@@ -19,6 +19,19 @@ class ONTSwapStatus(enum.Enum):
     cancelled = 'cancelled'
 
 
+class ONTMigrationStatus(enum.Enum):
+    pending = 'pending'
+    started = 'started'
+    success = 'success'
+    failed = 'failed'
+    cancelled = 'cancelled'
+
+
+class VelopType(enum.Enum):
+    branded = 'branded'
+    unbranded = 'unbranded'
+
+
 class ONT(Base):
     __tablename__ = 'ont'
 
@@ -129,3 +142,50 @@ class ONTSWAP(Base):
 
     def __repr__(self):
         return repr(self)
+
+
+class ONTMIGRATION(Base):
+    __tablename__ = 'ont_migration'
+
+    id = Column(Integer, primary_key=True)
+    migration_status = Column(Enum(ONTMigrationStatus), default='pending')
+    sn = Column(String(length=64), nullable=False, comment='ONT SN')
+    ont_type = Column(Enum(CPEProvTypeENUM), nullable=False)
+    velop_type = Column(Enum(VelopType))
+    old_portid = Column(Integer, nullable=False, comment='OLD DB portid')
+    old_slotid = Column(Integer, nullable=False, comment='OLD DB slotid')
+    old_frameid = Column(Integer, nullable=False, comment='OLD DB frameid')
+    old_ontid = Column(Integer, nullable=False)
+    old_siteid = Column(Integer, nullable=False)
+    old_olt_ip = Column(INET, nullable=False)
+    old_sitename = Column(String(length=256), nullable=False)
+    old_ucr = Column(String(length=64), nullable=False)
+    new_olt_ip = Column(INET)
+    new_siteid = Column(Integer)
+    new_sitename = Column(String(length=256))
+    new_site_shortname = Column(String(length=12))
+    cust_id = Column(String(length=64), comment='Billing system Customer ID')
+    subs_id = Column(String(length=64), comment='Billing system Subscription ID')
+    old_ont_register_datetime = Column(DateTime)
+    old_service_provision_datetime = Column(DateTime)
+    ont_expunged = Column(Boolean, default=False)
+    ont_expunge_datetime = Column(DateTime)
+    new_db_record_required = Column(Boolean, default=False, comment='If DB records are required to be created')
+    new_db_record_created = Column(Boolean, default=False)
+    new_db_record_created_datetime = Column(DateTime)
+    fr_from_tr069_done = Column(Boolean, default=False, comment='Factory reset ONT from TR069 server')
+    fr_from_tr069_datetime = Column(DateTime)
+    deleted_from_tr069 = Column(Boolean, default=False)
+    deleted_from_tr069_datetime = Column(DateTime)
+    user = Column(String(length=256), nullable=False, comment='user who requested the swap')
+    task_request_datetime = Column(DateTime)
+    task_finish_datetime = Column(DateTime)
+    notification_sent_type = Column(String(length=24))
+    notification_sent_datetime = Column(DateTime)
+    cancel_reason = Column(String(length=256))
+    cancelled_by = Column(String(length=256), comment='user who cancelled the migration')
+    cancelled_at = Column(DateTime)
+    error = Column(String(length=256))
+
+    def __repr__(self):
+        return repr(self)
